pub enum Error {
ErrorInternalGeneric(Option<String>),
ErrorInternalUrlParsing,
ErrorSendingHttpRequest(Option<String>),
ErrorJsonParsing(Option<String>),
ErrorApiResponse(String),
ErrorParameter(Option<String>),
}Expand description
List of possible error as occurs from the operations
Variants
ErrorInternalGeneric(Option<String>)
Internal error for generic error combined altogether Contain optional error message
ErrorInternalUrlParsing
Internal error from parsing Url
ErrorSendingHttpRequest(Option<String>)
Error in sending HTTP request Contains optional error message
ErrorJsonParsing(Option<String>)
Error JSON parsing Contain optional error message
ErrorApiResponse(String)
Error from Api response back from upstream API server containing the error message
ErrorParameter(Option<String>)
Parameter to function error